@@ -38,11 +38,11 @@
 
 #define NGTCP2_BBR_EXTRA_ACKED_FILTERLEN 10
 
-#define NGTCP2_BBR_STARTUP_PACING_GAIN ((double)2.77)
+#define NGTCP2_BBR_STARTUP_PACING_GAIN_H 277
 
-#define NGTCP2_BBR_STARTUP_CWND_GAIN 2
+#define NGTCP2_BBR_STARTUP_CWND_GAIN_H 200
 
-#define NGTCP2_BBR_PROBE_RTT_CWND_GAIN ((double)0.5)
+#define NGTCP2_BBR_PROBE_RTT_CWND_GAIN_H 50
 
 #define NGTCP2_BBR_BETA_NUMER 7
 #define NGTCP2_BBR_BETA_DENOM 10
@@ -78,7 +78,7 @@ static void bbr_init_pacing_rate(ngtcp2_cc_bbr *bbr, ngtcp2_conn_stat *cstat);
 
 static void bbr_set_pacing_rate_with_gain(ngtcp2_cc_bbr *bbr,
                                           ngtcp2_conn_stat *cstat,
-                                          double pacing_gain);
+                                          uint64_t pacing_gain_h);
 
 static void bbr_set_pacing_rate(ngtcp2_cc_bbr *bbr, ngtcp2_conn_stat *cstat);
 
@@ -227,14 +227,15 @@ static void bbr_handle_restart_from_idle(ngtcp2_cc_bbr *bbr,
                                          ngtcp2_conn_stat *cstat,
                                          ngtcp2_tstamp ts);
 
-static uint64_t bbr_bdp_multiple(ngtcp2_cc_bbr *bbr, uint64_t bw, double gain);
+static uint64_t bbr_bdp_multiple(ngtcp2_cc_bbr *bbr, uint64_t bw,
+                                 uint64_t gain_h);
 
 static uint64_t bbr_quantization_budget(ngtcp2_cc_bbr *bbr,
                                         ngtcp2_conn_stat *cstat,
                                         uint64_t inflight);
 
 static uint64_t bbr_inflight(ngtcp2_cc_bbr *bbr, ngtcp2_conn_stat *cstat,
-                             uint64_t bw, double gain);
+                             uint64_t bw, uint64_t gain_h);
 
 static void bbr_update_max_inflight(ngtcp2_cc_bbr *bbr,
                                     ngtcp2_conn_stat *cstat);
@@ -406,33 +407,37 @@ static void bbr_check_startup_high_loss(ngtcp2_cc_bbr *bbr,
 }
 
 static void bbr_init_pacing_rate(ngtcp2_cc_bbr *bbr, ngtcp2_conn_stat *cstat) {
-  double nominal_bandwidth = (double)bbr->initial_cwnd;
-
-  cstat->pacing_rate = NGTCP2_BBR_STARTUP_PACING_GAIN * nominal_bandwidth /
-                       (double)NGTCP2_MILLISECONDS;
+  cstat->pacing_interval = NGTCP2_MILLISECONDS * 100 /
+                           NGTCP2_BBR_STARTUP_PACING_GAIN_H / bbr->initial_cwnd;
 }
 
 static void bbr_set_pacing_rate_with_gain(ngtcp2_cc_bbr *bbr,
                                           ngtcp2_conn_stat *cstat,
-                                          double pacing_gain) {
-  double rate = pacing_gain * (double)bbr->bw *
-                (100 - NGTCP2_BBR_PACING_MARGIN_PERCENT) / 100 / NGTCP2_SECONDS;
+                                          uint64_t pacing_gain_h) {
+  ngtcp2_duration interval;
 
-  if (bbr->filled_pipe || rate > cstat->pacing_rate) {
-    cstat->pacing_rate = rate;
+  if (bbr->bw == 0) {
+    return;
+  }
+
+  interval = NGTCP2_SECONDS * 100 * 100 / pacing_gain_h / bbr->bw /
+             (100 - NGTCP2_BBR_PACING_MARGIN_PERCENT);
+
+  if (bbr->filled_pipe || interval < cstat->pacing_interval) {
+    cstat->pacing_interval = interval;
   }
 }
 
 static void bbr_set_pacing_rate(ngtcp2_cc_bbr *bbr, ngtcp2_conn_stat *cstat) {
-  bbr_set_pacing_rate_with_gain(bbr, cstat, bbr->pacing_gain);
+  bbr_set_pacing_rate_with_gain(bbr, cstat, bbr->pacing_gain_h);
 }
 
 static void bbr_enter_startup(ngtcp2_cc_bbr *bbr) {
   ngtcp2_log_info(bbr->cc.log, NGTCP2_LOG_EVENT_CCA, "bbr enter Startup");
 
   bbr->state = NGTCP2_BBR_STATE_STARTUP;
-  bbr->pacing_gain = NGTCP2_BBR_STARTUP_PACING_GAIN;
-  bbr->cwnd_gain = NGTCP2_BBR_STARTUP_CWND_GAIN;
+  bbr->pacing_gain_h = NGTCP2_BBR_STARTUP_PACING_GAIN_H;
+  bbr->cwnd_gain_h = NGTCP2_BBR_STARTUP_CWND_GAIN_H;
 }
 
 static void bbr_check_startup_done(ngtcp2_cc_bbr *bbr,
@@ -488,9 +493,9 @@ static void bbr_update_on_loss(ngtcp2_cc_bbr *cc, ngtcp2_conn_stat *cstat,
 static void bbr_update_latest_delivery_signals(ngtcp2_cc_bbr *bbr,
                                                ngtcp2_conn_stat *cstat) {
   bbr->loss_round_start = 0;
-  bbr->bw_latest = ngtcp2_max(bbr->bw_latest, cstat->delivery_rate_sec);
+  bbr->bw_latest = ngtcp2_max_uint64(bbr->bw_latest, cstat->delivery_rate_sec);
   bbr->inflight_latest =
-      ngtcp2_max(bbr->inflight_latest, bbr->rst->rs.delivered);
+      ngtcp2_max_uint64(bbr->inflight_latest, bbr->rst->rs.delivered);
 
   if (bbr->rst->rs.prior_delivered >= bbr->loss_round_delivered) {
     bbr->loss_round_delivered = bbr->rst->delivered;
@@ -532,7 +537,7 @@ static void bbr_update_congestion_signals(ngtcp2_cc_bbr *bbr,
 
 static void bbr_adapt_lower_bounds_from_congestion(ngtcp2_cc_bbr *bbr,
                                                    ngtcp2_conn_stat *cstat) {
-  if (!bbr->filled_pipe || bbr_is_in_probe_bw_state(bbr)) {
+  if (bbr_is_in_probe_bw_state(bbr)) {
     return;
   }
 
@@ -553,16 +558,17 @@ static void bbr_init_lower_bounds(ngtcp2_cc_bbr *bbr, ngtcp2_conn_stat *cstat) {
 }
 
 static void bbr_loss_lower_bounds(ngtcp2_cc_bbr *bbr) {
-  bbr->bw_lo = ngtcp2_max(bbr->bw_latest, bbr->bw_lo * NGTCP2_BBR_BETA_NUMER /
-                                              NGTCP2_BBR_BETA_DENOM);
-  bbr->inflight_lo = ngtcp2_max(bbr->inflight_latest,
-                                bbr->inflight_lo * NGTCP2_BBR_BETA_NUMER /
-                                    NGTCP2_BBR_BETA_DENOM);
+  bbr->bw_lo =
+      ngtcp2_max_uint64(bbr->bw_latest, bbr->bw_lo * NGTCP2_BBR_BETA_NUMER /
+                                            NGTCP2_BBR_BETA_DENOM);
+  bbr->inflight_lo = ngtcp2_max_uint64(
+      bbr->inflight_latest,
+      bbr->inflight_lo * NGTCP2_BBR_BETA_NUMER / NGTCP2_BBR_BETA_DENOM);
 }
 
 static void bbr_bound_bw_for_model(ngtcp2_cc_bbr *bbr) {
-  bbr->bw = ngtcp2_min(bbr->max_bw, bbr->bw_lo);
-  bbr->bw = ngtcp2_min(bbr->bw, bbr->bw_hi);
+  bbr->bw = ngtcp2_min_uint64(bbr->max_bw, bbr->bw_lo);
+  bbr->bw = ngtcp2_min_uint64(bbr->bw, bbr->bw_hi);
 }
 
 static void bbr_update_max_bw(ngtcp2_cc_bbr *bbr, ngtcp2_conn_stat *cstat,
@@ -628,7 +634,7 @@ static void bbr_update_ack_aggregation(ngtcp2_cc_bbr *bbr,
 
   bbr->extra_acked_delivered += ack->bytes_delivered;
   extra = bbr->extra_acked_delivered - expected_delivered;
-  extra = ngtcp2_min(extra, cstat->cwnd);
+  extra = ngtcp2_min_uint64(extra, cstat->cwnd);
 
   ngtcp2_window_filter_update(&bbr->extra_acked_filter, extra,
                               bbr->round_count);
@@ -640,14 +646,14 @@ static void bbr_enter_drain(ngtcp2_cc_bbr *bbr) {
   ngtcp2_log_info(bbr->cc.log, NGTCP2_LOG_EVENT_CCA, "bbr enter Drain");
 
   bbr->state = NGTCP2_BBR_STATE_DRAIN;
-  bbr->pacing_gain = 1. / NGTCP2_BBR_STARTUP_CWND_GAIN;
-  bbr->cwnd_gain = NGTCP2_BBR_STARTUP_CWND_GAIN;
+  bbr->pacing_gain_h = 100 * 100 / NGTCP2_BBR_STARTUP_CWND_GAIN_H;
+  bbr->cwnd_gain_h = NGTCP2_BBR_STARTUP_CWND_GAIN_H;
 }
 
 static void bbr_check_drain(ngtcp2_cc_bbr *bbr, ngtcp2_conn_stat *cstat,
                             ngtcp2_tstamp ts) {
   if (bbr->state == NGTCP2_BBR_STATE_DRAIN &&
-      cstat->bytes_in_flight <= bbr_inflight(bbr, cstat, bbr->bw, 1.0)) {
+      cstat->bytes_in_flight <= bbr_inflight(bbr, cstat, bbr->bw, 100)) {
     bbr_enter_probe_bw(bbr, ts);
   }
 }
@@ -671,8 +677,8 @@ static void bbr_start_probe_bw_down(ngtcp2_cc_bbr *bbr, ngtcp2_tstamp ts) {
   bbr_start_round(bbr);
 
   bbr->state = NGTCP2_BBR_STATE_PROBE_BW_DOWN;
-  bbr->pacing_gain = 0.9;
-  bbr->cwnd_gain = 2;
+  bbr->pacing_gain_h = 90;
+  bbr->cwnd_gain_h = 200;
 }
 
 static void bbr_start_probe_bw_cruise(ngtcp2_cc_bbr *bbr) {
@@ -680,8 +686,8 @@ static void bbr_start_probe_bw_cruise(ngtcp2_cc_bbr *bbr) {
                   "bbr start ProbeBW_CRUISE");
 
   bbr->state = NGTCP2_BBR_STATE_PROBE_BW_CRUISE;
-  bbr->pacing_gain = 1.0;
-  bbr->cwnd_gain = 2;
+  bbr->pacing_gain_h = 100;
+  bbr->cwnd_gain_h = 200;
 }
 
 static void bbr_start_probe_bw_refill(ngtcp2_cc_bbr *bbr) {
@@ -697,8 +703,8 @@ static void bbr_start_probe_bw_refill(ngtcp2_cc_bbr *bbr) {
   bbr_start_round(bbr);
 
   bbr->state = NGTCP2_BBR_STATE_PROBE_BW_REFILL;
-  bbr->pacing_gain = 1.0;
-  bbr->cwnd_gain = 2;
+  bbr->pacing_gain_h = 100;
+  bbr->cwnd_gain_h = 200;
 }
 
 static void bbr_start_probe_bw_up(ngtcp2_cc_bbr *bbr, ngtcp2_conn_stat *cstat,
@@ -711,8 +717,8 @@ static void bbr_start_probe_bw_up(ngtcp2_cc_bbr *bbr, ngtcp2_conn_stat *cstat,
 
   bbr->cycle_stamp = ts;
   bbr->state = NGTCP2_BBR_STATE_PROBE_BW_UP;
-  bbr->pacing_gain = 1.25;
-  bbr->cwnd_gain = 2.25;
+  bbr->pacing_gain_h = 125;
+  bbr->cwnd_gain_h = 225;
 
   bbr_raise_inflight_hi_slope(bbr, cstat);
 }
@@ -757,7 +763,7 @@ static void bbr_update_probe_bw_cycle_phase(ngtcp2_cc_bbr *bbr,
     break;
   case NGTCP2_BBR_STATE_PROBE_BW_UP:
     if (bbr_has_elapsed_in_phase(bbr, bbr->min_rtt, ts) &&
-        cstat->bytes_in_flight > bbr_inflight(bbr, cstat, bbr->max_bw, 1.25)) {
+        cstat->bytes_in_flight > bbr_inflight(bbr, cstat, bbr->max_bw, 125)) {
       bbr_start_probe_bw_down(bbr, ts);
     }
 
@@ -775,7 +781,7 @@ static int bbr_check_time_to_cruise(ngtcp2_cc_bbr *bbr, ngtcp2_conn_stat *cstat,
     return 0;
   }
 
-  if (cstat->bytes_in_flight <= bbr_inflight(bbr, cstat, bbr->max_bw, 1.0)) {
+  if (cstat->bytes_in_flight <= bbr_inflight(bbr, cstat, bbr->max_bw, 100)) {
     return 1;
   }
 
@@ -796,13 +802,13 @@ static uint64_t bbr_inflight_with_headroom(ngtcp2_cc_bbr *bbr,
     return UINT64_MAX;
   }
 
-  headroom = ngtcp2_max(cstat->max_tx_udp_payload_size,
-                        bbr->inflight_hi * NGTCP2_BBR_HEADROOM_NUMER /
-                            NGTCP2_BBR_HEADROOM_DENOM);
+  headroom = ngtcp2_max_uint64(cstat->max_tx_udp_payload_size,
+                               bbr->inflight_hi * NGTCP2_BBR_HEADROOM_NUMER /
+                                   NGTCP2_BBR_HEADROOM_DENOM);
   mpcwnd = min_pipe_cwnd(cstat->max_tx_udp_payload_size);
 
   if (bbr->inflight_hi > headroom) {
-    return ngtcp2_max(bbr->inflight_hi - headroom, mpcwnd);
+    return ngtcp2_max_uint64(bbr->inflight_hi - headroom, mpcwnd);
   }
 
   return mpcwnd;
@@ -813,8 +819,8 @@ static void bbr_raise_inflight_hi_slope(ngtcp2_cc_bbr *bbr,
   uint64_t growth_this_round = cstat->max_tx_udp_payload_size
                                << bbr->bw_probe_up_rounds;
 
-  bbr->bw_probe_up_rounds = ngtcp2_min(bbr->bw_probe_up_rounds + 1, 30);
-  bbr->probe_up_cnt = ngtcp2_max(cstat->cwnd / growth_this_round, 1) *
+  bbr->bw_probe_up_rounds = ngtcp2_min_size(bbr->bw_probe_up_rounds + 1, 30);
+  bbr->probe_up_cnt = ngtcp2_max_uint64(cstat->cwnd / growth_this_round, 1) *
                       cstat->max_tx_udp_payload_size;
 }
 
@@ -896,8 +902,8 @@ static void bbr_pick_probe_wait(ngtcp2_cc_bbr *bbr) {
 
   bbr->rand(&rand, 1, &bbr->rand_ctx);
 
-  bbr->bw_probe_wait = 2 * NGTCP2_SECONDS +
-                       (ngtcp2_tstamp)((double)rand / 255. * NGTCP2_SECONDS);
+  bbr->bw_probe_wait =
+      2 * NGTCP2_SECONDS + (ngtcp2_tstamp)(NGTCP2_SECONDS * rand / 255);
 }
 
 static int bbr_is_reno_coexistence_probe_time(ngtcp2_cc_bbr *bbr,
@@ -905,14 +911,14 @@ static int bbr_is_reno_coexistence_probe_time(ngtcp2_cc_bbr *bbr,
   uint64_t reno_rounds =
       bbr_target_inflight(bbr, cstat) / cstat->max_tx_udp_payload_size;
 
-  return bbr->rounds_since_bw_probe >= ngtcp2_min(reno_rounds, 63);
+  return bbr->rounds_since_bw_probe >= ngtcp2_min_uint64(reno_rounds, 63);
 }
 
 static uint64_t bbr_target_inflight(ngtcp2_cc_bbr *bbr,
                                     ngtcp2_conn_stat *cstat) {
-  uint64_t bdp = bbr_inflight(bbr, cstat, bbr->bw, 1.0);
+  uint64_t bdp = bbr_inflight(bbr, cstat, bbr->bw, 100);
 
-  return ngtcp2_min(bdp, cstat->cwnd);
+  return ngtcp2_min_uint64(bdp, cstat->cwnd);
 }
 
 static int bbr_check_inflight_too_high(ngtcp2_cc_bbr *bbr,
@@ -941,7 +947,7 @@ static void bbr_handle_inflight_too_high(ngtcp2_cc_bbr *bbr,
   bbr->bw_probe_samples = 0;
 
   if (!rs->is_app_limited) {
-    bbr->inflight_hi = ngtcp2_max(
+    bbr->inflight_hi = ngtcp2_max_uint64(
         rs->tx_in_flight, bbr_target_inflight(bbr, cstat) *
                               NGTCP2_BBR_BETA_NUMER / NGTCP2_BBR_BETA_DENOM);
   }
@@ -1047,8 +1053,8 @@ static void bbr_enter_probe_rtt(ngtcp2_cc_bbr *bbr) {
   ngtcp2_log_info(bbr->cc.log, NGTCP2_LOG_EVENT_CCA, "bbr enter ProbeRTT");
 
   bbr->state = NGTCP2_BBR_STATE_PROBE_RTT;
-  bbr->pacing_gain = 1;
-  bbr->cwnd_gain = NGTCP2_BBR_PROBE_RTT_CWND_GAIN;
+  bbr->pacing_gain_h = 100;
+  bbr->cwnd_gain_h = NGTCP2_BBR_PROBE_RTT_CWND_GAIN_H;
 }
 
 static void bbr_handle_probe_rtt(ngtcp2_cc_bbr *bbr, ngtcp2_conn_stat *cstat,
@@ -1119,14 +1125,15 @@ static void bbr_handle_restart_from_idle(ngtcp2_cc_bbr *bbr,
     bbr->extra_acked_interval_start = ts;
 
     if (bbr_is_in_probe_bw_state(bbr)) {
-      bbr_set_pacing_rate_with_gain(bbr, cstat, 1);
+      bbr_set_pacing_rate_with_gain(bbr, cstat, 100);
     } else if (bbr->state == NGTCP2_BBR_STATE_PROBE_RTT) {
       bbr_check_probe_rtt_done(bbr, cstat, ts);
     }
   }
 }
 
-static uint64_t bbr_bdp_multiple(ngtcp2_cc_bbr *bbr, uint64_t bw, double gain) {
+static uint64_t bbr_bdp_multiple(ngtcp2_cc_bbr *bbr, uint64_t bw,
+                                 uint64_t gain_h) {
   uint64_t bdp;
 
   if (bbr->min_rtt == UINT64_MAX) {
@@ -1135,7 +1142,7 @@ static uint64_t bbr_bdp_multiple(ngtcp2_cc_bbr *bbr, uint64_t bw, double gain) {
 
   bdp = bw * bbr->min_rtt / NGTCP2_SECONDS;
 
-  return (uint64_t)(gain * (double)bdp);
+  return (uint64_t)(bdp * gain_h / 100);
 }
 
 static uint64_t min_pipe_cwnd(size_t max_udp_payload_size) {
@@ -1147,9 +1154,9 @@ static uint64_t bbr_quantization_budget(ngtcp2_cc_bbr *bbr,
                                         uint64_t inflight) {
   bbr_update_offload_budget(bbr, cstat);
 
-  inflight = ngtcp2_max(inflight, bbr->offload_budget);
-  inflight =
-      ngtcp2_max(inflight, min_pipe_cwnd(cstat->max_tx_udp_payload_size));
+  inflight = ngtcp2_max_uint64(inflight, bbr->offload_budget);
+  inflight = ngtcp2_max_uint64(inflight,
+                               min_pipe_cwnd(cstat->max_tx_udp_payload_size));
 
   if (bbr->state == NGTCP2_BBR_STATE_PROBE_BW_UP) {
     inflight += 2 * cstat->max_tx_udp_payload_size;
@@ -1159,8 +1166,8 @@ static uint64_t bbr_quantization_budget(ngtcp2_cc_bbr *bbr,
 }
 
 static uint64_t bbr_inflight(ngtcp2_cc_bbr *bbr, ngtcp2_conn_stat *cstat,
-                             uint64_t bw, double gain) {
-  uint64_t inflight = bbr_bdp_multiple(bbr, bw, gain);
+                             uint64_t bw, uint64_t gain_h) {
+  uint64_t inflight = bbr_bdp_multiple(bbr, bw, gain_h);
 
   return bbr_quantization_budget(bbr, cstat, inflight);
 }
@@ -1172,7 +1179,8 @@ static void bbr_update_max_inflight(ngtcp2_cc_bbr *bbr,
   /* Not documented */
   /* bbr_update_aggregation_budget(bbr); */
 
-  inflight = bbr_bdp_multiple(bbr, bbr->bw, bbr->cwnd_gain) + bbr->extra_acked;
+  inflight =
+      bbr_bdp_multiple(bbr, bbr->bw, bbr->cwnd_gain_h) + bbr->extra_acked;
   bbr->max_inflight = bbr_quantization_budget(bbr, cstat, inflight);
 }
 
@@ -1191,15 +1199,16 @@ static void bbr_modulate_cwnd_for_recovery(ngtcp2_cc_bbr *bbr,
   if (ack->bytes_lost > 0) {
     if (cstat->cwnd > ack->bytes_lost) {
       cstat->cwnd -= ack->bytes_lost;
-      cstat->cwnd = ngtcp2_max(cstat->cwnd, 2 * cstat->max_tx_udp_payload_size);
+      cstat->cwnd =
+          ngtcp2_max_uint64(cstat->cwnd, 2 * cstat->max_tx_udp_payload_size);
     } else {
       cstat->cwnd = 2 * cstat->max_tx_udp_payload_size;
     }
   }
 
   if (bbr->packet_conservation) {
-    cstat->cwnd =
-        ngtcp2_max(cstat->cwnd, cstat->bytes_in_flight + ack->bytes_delivered);
+    cstat->cwnd = ngtcp2_max_uint64(cstat->cwnd, cstat->bytes_in_flight +
+                                                     ack->bytes_delivered);
   }
 }
 
@@ -1209,20 +1218,20 @@ static void bbr_save_cwnd(ngtcp2_cc_bbr *bbr, ngtcp2_conn_stat *cstat) {
     return;
   }
 
-  bbr->prior_cwnd = ngtcp2_max(bbr->prior_cwnd, cstat->cwnd);
+  bbr->prior_cwnd = ngtcp2_max_uint64(bbr->prior_cwnd, cstat->cwnd);
 }
 
 static void bbr_restore_cwnd(ngtcp2_cc_bbr *bbr, ngtcp2_conn_stat *cstat) {
-  cstat->cwnd = ngtcp2_max(cstat->cwnd, bbr->prior_cwnd);
+  cstat->cwnd = ngtcp2_max_uint64(cstat->cwnd, bbr->prior_cwnd);
 }
 
 static uint64_t bbr_probe_rtt_cwnd(ngtcp2_cc_bbr *bbr,
                                    ngtcp2_conn_stat *cstat) {
   uint64_t probe_rtt_cwnd =
-      bbr_bdp_multiple(bbr, bbr->bw, NGTCP2_BBR_PROBE_RTT_CWND_GAIN);
+      bbr_bdp_multiple(bbr, bbr->bw, NGTCP2_BBR_PROBE_RTT_CWND_GAIN_H);
   uint64_t mpcwnd = min_pipe_cwnd(cstat->max_tx_udp_payload_size);
 
-  return ngtcp2_max(probe_rtt_cwnd, mpcwnd);
+  return ngtcp2_max_uint64(probe_rtt_cwnd, mpcwnd);
 }
 
 static void bbr_bound_cwnd_for_probe_rtt(ngtcp2_cc_bbr *bbr,
@@ -1232,7 +1241,7 @@ static void bbr_bound_cwnd_for_probe_rtt(ngtcp2_cc_bbr *bbr,
   if (bbr->state == NGTCP2_BBR_STATE_PROBE_RTT) {
     probe_rtt_cwnd = bbr_probe_rtt_cwnd(bbr, cstat);
 
-    cstat->cwnd = ngtcp2_min(cstat->cwnd, probe_rtt_cwnd);
+    cstat->cwnd = ngtcp2_min_uint64(cstat->cwnd, probe_rtt_cwnd);
   }
 }
 
@@ -1246,14 +1255,14 @@ static void bbr_set_cwnd(ngtcp2_cc_bbr *bbr, ngtcp2_conn_stat *cstat,
   if (!bbr->packet_conservation) {
     if (bbr->filled_pipe) {
       cstat->cwnd += ack->bytes_delivered;
-      cstat->cwnd = ngtcp2_min(cstat->cwnd, bbr->max_inflight);
+      cstat->cwnd = ngtcp2_min_uint64(cstat->cwnd, bbr->max_inflight);
     } else if (cstat->cwnd < bbr->max_inflight ||
                bbr->rst->delivered < bbr->initial_cwnd) {
       cstat->cwnd += ack->bytes_delivered;
     }
 
     mpcwnd = min_pipe_cwnd(cstat->max_tx_udp_payload_size);
-    cstat->cwnd = ngtcp2_max(cstat->cwnd, mpcwnd);
+    cstat->cwnd = ngtcp2_max_uint64(cstat->cwnd, mpcwnd);
   }
 
   bbr_bound_cwnd_for_probe_rtt(bbr, cstat);
@@ -1273,26 +1282,30 @@ static void bbr_bound_cwnd_for_model(ngtcp2_cc_bbr *bbr,
     cap = bbr_inflight_with_headroom(bbr, cstat);
   }
 
-  cap = ngtcp2_min(cap, bbr->inflight_lo);
-  cap = ngtcp2_max(cap, mpcwnd);
+  cap = ngtcp2_min_uint64(cap, bbr->inflight_lo);
+  cap = ngtcp2_max_uint64(cap, mpcwnd);
 
-  cstat->cwnd = ngtcp2_min(cstat->cwnd, cap);
+  cstat->cwnd = ngtcp2_min_uint64(cstat->cwnd, cap);
 }
 
 static void bbr_set_send_quantum(ngtcp2_cc_bbr *bbr, ngtcp2_conn_stat *cstat) {
   size_t floor, send_quantum;
   (void)bbr;
 
-  if (cstat->pacing_rate < 1.2 * 1024 * 1024 / 8 / NGTCP2_SECONDS) {
+  if (cstat->pacing_interval > (NGTCP2_SECONDS * 8 * 10 / 12) >> 20) {
     floor = cstat->max_tx_udp_payload_size;
   } else {
     floor = 2 * cstat->max_tx_udp_payload_size;
   }
 
-  send_quantum = (size_t)(cstat->pacing_rate * NGTCP2_MILLISECONDS);
+  if (cstat->pacing_interval) {
+    send_quantum = (size_t)(NGTCP2_MILLISECONDS / cstat->pacing_interval);
+    send_quantum = ngtcp2_min_size(send_quantum, 64 * 1024);
+  } else {
+    send_quantum = 64 * 1024;
+  }
 
-  send_quantum = ngtcp2_min(send_quantum, 64 * 1024);
-  cstat->send_quantum = ngtcp2_max(send_quantum, floor);
+  cstat->send_quantum = ngtcp2_max_size(send_quantum, floor);
 }
 
 static int in_congestion_recovery(const ngtcp2_conn_stat *cstat,
@@ -1323,7 +1336,7 @@ static void bbr_handle_recovery(ngtcp2_cc_bbr *bbr, ngtcp2_conn_stat *cstat,
     bbr_save_cwnd(bbr, cstat);
     cstat->cwnd =
         cstat->bytes_in_flight +
-        ngtcp2_max(ack->bytes_delivered, cstat->max_tx_udp_payload_size);
+        ngtcp2_max_uint64(ack->bytes_delivered, cstat->max_tx_udp_payload_size);
 
     cstat->congestion_recovery_start_ts = bbr->congestion_recovery_start_ts;
     bbr->congestion_recovery_start_ts = UINT64_MAX;
@@ -1346,7 +1359,7 @@ static void bbr_cc_congestion_event(ngtcp2_cc *cc, ngtcp2_conn_stat *cstat,
                                     ngtcp2_tstamp sent_ts, ngtcp2_tstamp ts) {
   ngtcp2_cc_bbr *bbr = ngtcp2_struct_of(cc, ngtcp2_cc_bbr, cc);
 
-  if (!bbr->filled_pipe || bbr->in_loss_recovery ||
+  if (bbr->in_loss_recovery ||
       bbr->congestion_recovery_start_ts != UINT64_MAX ||
       in_congestion_recovery(cstat, sent_ts)) {
     return;
@@ -1370,9 +1383,11 @@ static void bbr_cc_on_spurious_congestion(ngtcp2_cc *cc,
     bbr_restore_cwnd(bbr, cstat);
     bbr->full_bw_count = 0;
     bbr->loss_in_round = 0;
-    bbr->inflight_lo = ngtcp2_max(bbr->inflight_lo, bbr->prior_inflight_lo);
-    bbr->inflight_hi = ngtcp2_max(bbr->inflight_hi, bbr->prior_inflight_hi);
-    bbr->bw_lo = ngtcp2_max(bbr->bw_lo, bbr->prior_bw_lo);
+    bbr->inflight_lo =
+        ngtcp2_max_uint64(bbr->inflight_lo, bbr->prior_inflight_lo);
+    bbr->inflight_hi =
+        ngtcp2_max_uint64(bbr->inflight_hi, bbr->prior_inflight_hi);
+    bbr->bw_lo = ngtcp2_max_uint64(bbr->bw_lo, bbr->prior_bw_lo);
   }
 }
 
@@ -1389,8 +1404,8 @@ static void bbr_cc_on_persistent_congestion(ngtcp2_cc *cc,
 
   bbr_save_cwnd(bbr, cstat);
   cstat->cwnd = cstat->bytes_in_flight + cstat->max_tx_udp_payload_size;
-  cstat->cwnd =
-      ngtcp2_max(cstat->cwnd, min_pipe_cwnd(cstat->max_tx_udp_payload_size));
+  cstat->cwnd = ngtcp2_max_uint64(
+      cstat->cwnd, min_pipe_cwnd(cstat->max_tx_udp_payload_size));
 }
 
 static void bbr_cc_on_ack_recv(ngtcp2_cc *cc, ngtcp2_conn_stat *cstat,
