@@ -95,9 +95,8 @@
 /* NGTCP2_MAX_PKT_NUM is the maximum packet number. */
 #define NGTCP2_MAX_PKT_NUM ((int64_t)((1ll << 62) - 1))
 
-/* NGTCP2_MIN_PKT_EXPANDLEN is the minimum packet size expansion in
-   addition to the minimum DCID length to hide/trigger Stateless
-   Reset. */
+/* NGTCP2_MIN_PKT_EXPANDLEN is the minimum packet size expansion to
+   hide/trigger Stateless Reset. */
 #define NGTCP2_MIN_PKT_EXPANDLEN 22
 
 /* NGTCP2_RETRY_TAGLEN is the length of Retry packet integrity tag. */
@@ -144,38 +143,36 @@ typedef struct ngtcp2_pkt_retry {
   uint8_t tag[NGTCP2_RETRY_TAGLEN];
 } ngtcp2_pkt_retry;
 
-typedef enum {
-  NGTCP2_FRAME_PADDING = 0x00,
-  NGTCP2_FRAME_PING = 0x01,
-  NGTCP2_FRAME_ACK = 0x02,
-  NGTCP2_FRAME_ACK_ECN = 0x03,
-  NGTCP2_FRAME_RESET_STREAM = 0x04,
-  NGTCP2_FRAME_STOP_SENDING = 0x05,
-  NGTCP2_FRAME_CRYPTO = 0x06,
-  NGTCP2_FRAME_NEW_TOKEN = 0x07,
-  NGTCP2_FRAME_STREAM = 0x08,
-  NGTCP2_FRAME_MAX_DATA = 0x10,
-  NGTCP2_FRAME_MAX_STREAM_DATA = 0x11,
-  NGTCP2_FRAME_MAX_STREAMS_BIDI = 0x12,
-  NGTCP2_FRAME_MAX_STREAMS_UNI = 0x13,
-  NGTCP2_FRAME_DATA_BLOCKED = 0x14,
-  NGTCP2_FRAME_STREAM_DATA_BLOCKED = 0x15,
-  NGTCP2_FRAME_STREAMS_BLOCKED_BIDI = 0x16,
-  NGTCP2_FRAME_STREAMS_BLOCKED_UNI = 0x17,
-  NGTCP2_FRAME_NEW_CONNECTION_ID = 0x18,
-  NGTCP2_FRAME_RETIRE_CONNECTION_ID = 0x19,
-  NGTCP2_FRAME_PATH_CHALLENGE = 0x1a,
-  NGTCP2_FRAME_PATH_RESPONSE = 0x1b,
-  NGTCP2_FRAME_CONNECTION_CLOSE = 0x1c,
-  NGTCP2_FRAME_CONNECTION_CLOSE_APP = 0x1d,
-  NGTCP2_FRAME_HANDSHAKE_DONE = 0x1e,
-  NGTCP2_FRAME_DATAGRAM = 0x30,
-  NGTCP2_FRAME_DATAGRAM_LEN = 0x31,
-} ngtcp2_frame_type;
+#define NGTCP2_FRAME_PADDING 0x00
+#define NGTCP2_FRAME_PING 0x01
+#define NGTCP2_FRAME_ACK 0x02
+#define NGTCP2_FRAME_ACK_ECN 0x03
+#define NGTCP2_FRAME_RESET_STREAM 0x04
+#define NGTCP2_FRAME_STOP_SENDING 0x05
+#define NGTCP2_FRAME_CRYPTO 0x06
+#define NGTCP2_FRAME_NEW_TOKEN 0x07
+#define NGTCP2_FRAME_STREAM 0x08
+#define NGTCP2_FRAME_MAX_DATA 0x10
+#define NGTCP2_FRAME_MAX_STREAM_DATA 0x11
+#define NGTCP2_FRAME_MAX_STREAMS_BIDI 0x12
+#define NGTCP2_FRAME_MAX_STREAMS_UNI 0x13
+#define NGTCP2_FRAME_DATA_BLOCKED 0x14
+#define NGTCP2_FRAME_STREAM_DATA_BLOCKED 0x15
+#define NGTCP2_FRAME_STREAMS_BLOCKED_BIDI 0x16
+#define NGTCP2_FRAME_STREAMS_BLOCKED_UNI 0x17
+#define NGTCP2_FRAME_NEW_CONNECTION_ID 0x18
+#define NGTCP2_FRAME_RETIRE_CONNECTION_ID 0x19
+#define NGTCP2_FRAME_PATH_CHALLENGE 0x1a
+#define NGTCP2_FRAME_PATH_RESPONSE 0x1b
+#define NGTCP2_FRAME_CONNECTION_CLOSE 0x1c
+#define NGTCP2_FRAME_CONNECTION_CLOSE_APP 0x1d
+#define NGTCP2_FRAME_HANDSHAKE_DONE 0x1e
+#define NGTCP2_FRAME_DATAGRAM 0x30
+#define NGTCP2_FRAME_DATAGRAM_LEN 0x31
 
 /* ngtcp2_stream represents STREAM and CRYPTO frames. */
 typedef struct ngtcp2_stream {
-  uint8_t type;
+  uint64_t type;
   /**
    * flags of decoded STREAM frame.  This gets ignored when encoding
    * STREAM frame.  CRYPTO frame does not include this field, and must
@@ -203,7 +200,7 @@ typedef struct ngtcp2_ack_range {
 } ngtcp2_ack_range;
 
 typedef struct ngtcp2_ack {
-  uint8_t type;
+  uint64_t type;
   int64_t largest_ack;
   uint64_t ack_delay;
   /**
@@ -222,7 +219,7 @@ typedef struct ngtcp2_ack {
 } ngtcp2_ack;
 
 typedef struct ngtcp2_padding {
-  uint8_t type;
+  uint64_t type;
   /**
    * The length of contiguous PADDING frames.
    */
@@ -230,14 +227,14 @@ typedef struct ngtcp2_padding {
 } ngtcp2_padding;
 
 typedef struct ngtcp2_reset_stream {
-  uint8_t type;
+  uint64_t type;
   int64_t stream_id;
   uint64_t app_error_code;
   uint64_t final_size;
 } ngtcp2_reset_stream;
 
 typedef struct ngtcp2_connection_close {
-  uint8_t type;
+  uint64_t type;
   uint64_t error_code;
   uint64_t frame_type;
   size_t reasonlen;
@@ -245,7 +242,7 @@ typedef struct ngtcp2_connection_close {
 } ngtcp2_connection_close;
 
 typedef struct ngtcp2_max_data {
-  uint8_t type;
+  uint64_t type;
   /**
    * max_data is Maximum Data.
    */
@@ -253,38 +250,38 @@ typedef struct ngtcp2_max_data {
 } ngtcp2_max_data;
 
 typedef struct ngtcp2_max_stream_data {
-  uint8_t type;
+  uint64_t type;
   int64_t stream_id;
   uint64_t max_stream_data;
 } ngtcp2_max_stream_data;
 
 typedef struct ngtcp2_max_streams {
-  uint8_t type;
+  uint64_t type;
   uint64_t max_streams;
 } ngtcp2_max_streams;
 
 typedef struct ngtcp2_ping {
-  uint8_t type;
+  uint64_t type;
 } ngtcp2_ping;
 
 typedef struct ngtcp2_data_blocked {
-  uint8_t type;
+  uint64_t type;
   uint64_t offset;
 } ngtcp2_data_blocked;
 
 typedef struct ngtcp2_stream_data_blocked {
-  uint8_t type;
+  uint64_t type;
   int64_t stream_id;
   uint64_t offset;
 } ngtcp2_stream_data_blocked;
 
 typedef struct ngtcp2_streams_blocked {
-  uint8_t type;
+  uint64_t type;
   uint64_t max_streams;
 } ngtcp2_streams_blocked;
 
 typedef struct ngtcp2_new_connection_id {
-  uint8_t type;
+  uint64_t type;
   uint64_t seq;
   uint64_t retire_prior_to;
   ngtcp2_cid cid;
@@ -292,38 +289,38 @@ typedef struct ngtcp2_new_connection_id {
 } ngtcp2_new_connection_id;
 
 typedef struct ngtcp2_stop_sending {
-  uint8_t type;
+  uint64_t type;
   int64_t stream_id;
   uint64_t app_error_code;
 } ngtcp2_stop_sending;
 
 typedef struct ngtcp2_path_challenge {
-  uint8_t type;
+  uint64_t type;
   uint8_t data[NGTCP2_PATH_CHALLENGE_DATALEN];
 } ngtcp2_path_challenge;
 
 typedef struct ngtcp2_path_response {
-  uint8_t type;
+  uint64_t type;
   uint8_t data[NGTCP2_PATH_CHALLENGE_DATALEN];
 } ngtcp2_path_response;
 
 typedef struct ngtcp2_new_token {
-  uint8_t type;
+  uint64_t type;
   uint8_t *token;
   size_t tokenlen;
 } ngtcp2_new_token;
 
 typedef struct ngtcp2_retire_connection_id {
-  uint8_t type;
+  uint64_t type;
   uint64_t seq;
 } ngtcp2_retire_connection_id;
 
 typedef struct ngtcp2_handshake_done {
-  uint8_t type;
+  uint64_t type;
 } ngtcp2_handshake_done;
 
 typedef struct ngtcp2_datagram {
-  uint8_t type;
+  uint64_t type;
   /* dgram_id is an opaque identifier chosen by an application. */
   uint64_t dgram_id;
   /* datacnt is the number of elements that data contains. */
@@ -338,7 +335,7 @@ typedef struct ngtcp2_datagram {
 } ngtcp2_datagram;
 
 typedef union ngtcp2_frame {
-  uint8_t type;
+  uint64_t type;
   ngtcp2_stream stream;
   ngtcp2_ack ack;
   ngtcp2_padding padding;
@@ -1122,12 +1119,12 @@ ngtcp2_ssize ngtcp2_pkt_encode_datagram_frame(uint8_t *out, size_t outlen,
 
 /*
  * ngtcp2_pkt_adjust_pkt_num find the full 64 bits packet number for
- * |pkt_num|, which is expected to be least significant |n| bits.  The
+ * |pkt_num|, which is encoded in |pkt_numlen| bytes.  The
  * |max_pkt_num| is the highest successfully authenticated packet
  * number.
  */
 int64_t ngtcp2_pkt_adjust_pkt_num(int64_t max_pkt_num, int64_t pkt_num,
-                                  size_t n);
+                                  size_t pkt_numlen);
 
 /*
  * ngtcp2_pkt_validate_ack checks that ack is malformed or not.
