@@ -1,4 +1,4 @@
-/*  Copyright (C) 2022 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
+/*  Copyright (C) 2024 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -95,6 +95,47 @@ typedef enum {
 	KNOT_RCODE_BADCOOKIE = 23  /*!< Bad/missing server cookie. */
 } knot_rcode_t;
 
+/*!
+ * \brief Extended error codes as in EDNS option #15.
+ *
+ * \note The default -1 value must be filtered out before storing to uint16_t!
+ *
+ * https://www.iana.org/assignments/dns-parameters/dns-parameters.xml#extended-dns-error-codes
+ */
+typedef enum {
+	KNOT_EDNS_EDE_NONE             = -1,
+	KNOT_EDNS_EDE_OTHER            = 0,
+	KNOT_EDNS_EDE_DNSKEY_ALG       = 1,
+	KNOT_EDNS_EDE_DS_DIGEST        = 2,
+	KNOT_EDNS_EDE_STALE            = 3,
+	KNOT_EDNS_EDE_FORGED           = 4,
+	KNOT_EDNS_EDE_INDETERMINATE    = 5,
+	KNOT_EDNS_EDE_BOGUS            = 6,
+	KNOT_EDNS_EDE_SIG_EXPIRED      = 7,
+	KNOT_EDNS_EDE_SIG_NOTYET       = 8,
+	KNOT_EDNS_EDE_DNSKEY_MISS      = 9,
+	KNOT_EDNS_EDE_RRSIG_MISS       = 10,
+	KNOT_EDNS_EDE_DNSKEY_BIT       = 11,
+	KNOT_EDNS_EDE_NSEC_MISS        = 12,
+	KNOT_EDNS_EDE_CACHED_ERR       = 13,
+	KNOT_EDNS_EDE_NOT_READY        = 14,
+	KNOT_EDNS_EDE_BLOCKED          = 15,
+	KNOT_EDNS_EDE_CENSORED         = 16,
+	KNOT_EDNS_EDE_FILTERED         = 17,
+	KNOT_EDNS_EDE_PROHIBITED       = 18,
+	KNOT_EDNS_EDE_STALE_NXD        = 19,
+	KNOT_EDNS_EDE_NOTAUTH          = 20,
+	KNOT_EDNS_EDE_NOTSUP           = 21,
+	KNOT_EDNS_EDE_NREACH_AUTH      = 22,
+	KNOT_EDNS_EDE_NETWORK          = 23,
+	KNOT_EDNS_EDE_INV_DATA         = 24,
+	KNOT_EDNS_EDE_EXPIRED_INV      = 25,
+	KNOT_EDNS_EDE_TOO_EARLY        = 26,
+	KNOT_EDNS_EDE_NSEC3_ITERS      = 27,
+	KNOT_EDNS_EDE_NONCONF_POLICY   = 28,
+	KNOT_EDNS_EDE_SYNTHESIZED      = 29,
+} knot_edns_ede_t;
+
 /*!
  * \brief DNS packet section identifiers.
  */
@@ -104,63 +145,10 @@ typedef enum {
 	KNOT_ADDITIONAL   = 2
 } knot_section_t;
 
-/*!
- * \brief DS digest lengths.
- */
-enum knot_ds_algorithm_len
-{
-	KNOT_DS_DIGEST_LEN_SHA1   = 20, /*!< RFC 3658 */
-	KNOT_DS_DIGEST_LEN_SHA256 = 32, /*!< RFC 4509 */
-	KNOT_DS_DIGEST_LEN_GOST   = 32, /*!< RFC 5933 */
-	KNOT_DS_DIGEST_LEN_SHA384 = 48  /*!< RFC 6605 */
-};
-
-/*!
- * \brief Constants for DNSSEC algorithm types.
- *
- * Source: https://www.iana.org/assignments/ds-rr-types/ds-rr-types.xml
- */
-typedef enum {
-	KNOT_DS_ALG_SHA1   = 1,
-	KNOT_DS_ALG_SHA256 = 2,
-	KNOT_DS_ALG_GOST   = 3,
-	KNOT_DS_ALG_SHA384 = 4
-} knot_ds_algorithm_t;
-
-/*!
- * \brief DNSSEC algorithm numbers.
- *
- * https://www.iana.org/assignments/dns-sec-alg-numbers/dns-sec-alg-numbers.xml
- */
-typedef enum {
-	KNOT_DNSSEC_ALG_DELETE             =   0,
-	KNOT_DNSSEC_ALG_RSAMD5             =   1,
-	KNOT_DNSSEC_ALG_DH                 =   2,
-	KNOT_DNSSEC_ALG_DSA                =   3,
-
-	KNOT_DNSSEC_ALG_RSASHA1            =   5,
-	KNOT_DNSSEC_ALG_DSA_NSEC3_SHA1     =   6,
-	KNOT_DNSSEC_ALG_RSASHA1_NSEC3_SHA1 =   7,
-	KNOT_DNSSEC_ALG_RSASHA256          =   8,
-
-	KNOT_DNSSEC_ALG_RSASHA512          =  10,
-
-	KNOT_DNSSEC_ALG_ECC_GOST           =  12,
-	KNOT_DNSSEC_ALG_ECDSAP256SHA256    =  13,
-	KNOT_DNSSEC_ALG_ECDSAP384SHA384    =  14,
-
-	KNOT_DNSSEC_ALG_ED25519            =  15,
-	KNOT_DNSSEC_ALG_ED448              =  16,
-
-	KNOT_DNSSEC_ALG_INDIRECT           = 252,
-	KNOT_DNSSEC_ALG_PRIVATEDNS         = 253,
-	KNOT_DNSSEC_ALG_PRIVATEOID         = 254
-} knot_dnssec_algorithm_t;
-
 /*!
  * \brief Service Binding (SVCB) Parameter Registry
  *
- * https://tools.ietf.org/html/draft-ietf-dnsop-svcb-https-05 // FIXME
+ * https://www.iana.org/assignments/dns-svcb/dns-svcb.xhtml
  */
 typedef enum {
 	KNOT_SVCB_PARAM_MANDATORY = 0,
@@ -170,6 +158,8 @@ typedef enum {
 	KNOT_SVCB_PARAM_IPV4HINT  = 4,
 	KNOT_SVCB_PARAM_ECH       = 5,
 	KNOT_SVCB_PARAM_IPV6HINT  = 6,
+	KNOT_SVCB_PARAM_DOHPATH   = 7,
+	KNOT_SVCB_PARAM_OHTTP     = 8,
 } knot_svcb_param_t;
 
 /*! @} */
